<?php // Please do not edit this file. If you do, save as UTF-8 without BOM!

/* Copyright 2019-2022 Martin Janecke <mouse@prlbr.de>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* This submodule displays a search form compatible with the main x-mouse
 * module. It redirects search requests to a page where the main module is
 * supposed to be invoked to do the search and present the results. Example use:
 *
 * [x-mouse/goto:Find it!]->/search
 */

// declare (strict_types = 1); // only during development

namespace prlbr\mouse;

require_once __DIR__ . '/../assets/functions.php';


/* Returnig a closure that returns the form instead of returning the form
 * directly enables the Aneamal translator to use this module multiple times
 * with a single include.
 */
return function (
	array $_
):	string
{
	// where the main module is supposed to be invoked in a page
	$target = $_['hrefs'][0];
	if (strpos ($target, '#') === false):
		$target .= '#mouse';
	endif;
	$action = esc ($target);

	// ARIA label for the search button
	if (isset ($_['clue'])):
		$button = esc ($_['clue']);
	else:
		require_once __DIR__ . '/../assets/i18n.php';
		$button = esc (i18n ($_['lang'], 'Search'));
	endif;
	$label = $button === ''? '': " aria-label='$button'";

	// Return the HTML code for the search form. The default button text is
	// U+1F50D LEFT-POINTING MAGNIFYING GLASS plus U+FE0E VARIATION SELECTOR-15.
	// Apparently some browsers/operating systems ignore the text variation
	// selector though and display the magnifying glass as emoji anyway.
	return <<<MUS
		<form action='$action' method='post' role='search' class='mouse-form'>
		<input name='mouse-1' type='search' maxlength='2048' required><button type='submit'$label><span>\xF0\x9F\x94\x8D\xEF\xB8\x8E</span></button>
		</form>
		MUS;
};

// The End