<?php // Please do not edit this file. If you do, save as UTF-8 without BOM!

/* Copyright 2019-2022 Martin Janecke <mouse@prlbr.de>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* This submodule displays the newest pages that the crawler of the main module
 * x-mouse found. The number of displayed hits can be configured. Use this
 * submodule with the same links provided to the main module. Example:
 *
 * @x-mouse: news=8
 * [x-mouse/news]->https://example.org/
 */

// declare (strict_types = 1); // only during development

namespace prlbr\mouse;

require_once __DIR__ . '/../assets/functions.php';


/* Returnig a closure that returns the form instead of returning the form
 * directly enables the Aneamal translator to use this module multiple times
 * with a single include.
 */
return function (
	array $_,
	int $max = 99
):	string
{
	$hash = realm ($_['links']);
	$json = "$_[root]/aneamal/private/mouse/$hash/news.json";
	$hits = json_decode ((string) @file_get_contents ($json), true) ?: [];

	// get the number of hits to be shown; can be set with @x-mouse:news=...
	$parameters = parameters ($_['meta']);
	$snippetlen = intval ($parameters['snippet'] ?? 0);
	$count = intval ($parameters['news'] ?? 1);

	// prepare HTML output
	$out[] = "<div class='mouse-news'>\n<ul class='mouse-list'>";
	foreach (array_slice (array_reverse ($hits), 0, $count) as $result):
		$out[] = item ($result, $snippetlen, "data-time='" . esc ((string) $result['timestamp']) . "'");
	endforeach;
	$out[] = "</ul>\n</div>";

	return implode ("\n", $out);
};

// The End